# NEW RELEASES

There are steps to consider when releasing a new version of this software:

1. All executes on main branch
2. Documentation builds on `main` branch.
3. Publish to Pypi happens when a new release is `created`
